package com.hfkj.service.order;

import com.alibaba.fastjson.JSONObject;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.RandomUtils;
import com.hfkj.common.utils.RedisUtil;
import com.hfkj.entity.*;
import com.hfkj.model.order.OrderChildModel;
import com.hfkj.model.order.OrderModel;
import com.hfkj.service.coupon.BsOrderCouponNoService;
import com.hfkj.service.coupon.BsOrderCouponService;
import com.hfkj.service.coupon.channel.HuiLianTongCouponService;
import com.hfkj.service.goods.*;
import com.hfkj.service.hlt.HuiLianTongUnionCardService;
import com.hfkj.sysenum.GoodsVpdSourceEnum;
import com.hfkj.sysenum.order.OrderChildProductTypeEnum;
import com.hfkj.sysenum.order.OrderChildStatusEnum;
import com.hfkj.sysenum.order.OrderCouponNoStatusEnum;
import com.hfkj.sysenum.order.OrderGoodsStatusEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.Map;

/**
 * 创建订单业务
 * @className: OrderCreateService
 * @author: HuRui
 * @date: 2024/5/7
 **/
@Component
public class OrderCreateService {
    Logger log = LoggerFactory.getLogger(OrderCreateService.class);

    @Resource
    private BsOrderCouponService orderCouponService;
    @Resource
    private BsOrderCouponNoService orderCouponNoService;
    @Resource
    private GoodsMsgService goodsMsgService;
    @Resource
    private GoodsSpecsService goodsSpecsService;
    @Resource
    private GoodsVpdService goodsVpdService;
    @Resource
    private GoodsUserAddressService goodsUserAddressService;
    @Resource
    private BsOrderGoodsService bsOrderGoodsService;
    @Resource
    private GoodsShoppingCartService shoppingCartService;

    /**
     * 事务产品
     * @param orderChild 子订单
     * @throws Exception
     */
    public OrderChildModel product(OrderModel order, OrderChildModel orderChild) throws Exception {
        // 查询商品
        GoodsMsg goodsMsg = goodsMsgService.queryDetail(orderChild.getProductId());
        if (goodsMsg == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未知的商品");
        }
        if (goodsMsg.getStatus() != 1) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, goodsMsg.getTitle()+"暂无法就进行购买");
        }
        // 查询商品规格
        GoodsSpecs goodsSpecs = goodsSpecsService.queryDetail(orderChild.getProductSpecId());
        if (goodsSpecs == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未知的商品规格");
        }
        if (goodsSpecs.getStock() <= 0) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "库存不足");
        }
        // 减少库存
        goodsSpecsService.editStockNum(orderChild.getProductSpecId(), orderChild.getProductCount(), 2);

        JSONObject businessObj = orderChild.getBusiness()==null?new JSONObject(): new JSONObject((Map<String, Object>) orderChild.getBusiness());
        if (businessObj.getLong("shopCartId") != null) {
            shoppingCartService.delete(businessObj.getLong("shopCartId"));
        }
        orderChild.setMerId(goodsMsg.getMerId());
        orderChild.setProductName(goodsMsg.getTitle());
        orderChild.setProductImg(goodsMsg.getListImg());
        orderChild.setProductSpecName(goodsSpecs.getName());
        orderChild.setProductPrice(goodsSpecs.getSalePrice());
        // 虚拟
        // 查询商品虚拟信息
        GoodsVpd goodsVpd = goodsVpdService.queryDetailBySpecsId(goodsSpecs.getId());
        if (goodsVpd == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未知的商品虚拟规格");
        }
        // 虚拟配置
        orderChild.setBusiness(goodsVpd);

        // 创建卡券订单
        BsOrderCoupon orderCoupon = new BsOrderCoupon();
        orderCoupon.setOrderNo(orderChild.getOrderNo());
        orderCoupon.setChildOrderNo(orderChild.getChildOrderNo());
        orderCoupon.setMerId(orderChild.getMerId());
        orderCoupon.setUserId(order.getUserId());
        orderCoupon.setUserPhone(order.getUserPhone());
        orderCoupon.setGoodsId(goodsMsg.getId());
        orderCoupon.setGoodsName(goodsMsg.getTitle());
        orderCoupon.setGoodsTypeId(goodsMsg.getGoodsType());
        orderCoupon.setGoodsTypeName(goodsMsg.getGoodsTypeName());
        orderCoupon.setGoodsBrandId(goodsMsg.getGoodsBrand());
        orderCoupon.setGoodsBrandName(goodsMsg.getGoodsBrandName());
        orderCoupon.setGoodsSpecsId(goodsSpecs.getId());
        orderCoupon.setGoodsSpecsName(goodsSpecs.getName());
        orderCoupon.setGoodsSpescOriginalPrice(goodsSpecs.getOriginalPrice());
        orderCoupon.setGoodsVpdId(goodsVpd.getId());
        orderCoupon.setGoodsVpdKey(goodsVpd.getKey());
        orderCoupon.setGoodsVpdSource(goodsVpd.getSource());
        orderCoupon.setGoodsCount(orderChild.getProductCount());
        orderCoupon.setStatus(OrderChildStatusEnum.status1.getCode());
        orderCouponService.editData(orderCoupon);

        for (int i = 0; i < orderCoupon.getGoodsCount(); i++) {
            // 卡券订单卡密
            BsOrderCouponNo orderCouponNo = new BsOrderCouponNo();
            orderCouponNo.setCouponOrderId(orderCoupon.getId());
            orderCouponNo.setOrderNo(orderCoupon.getId() + RandomUtils.number(6, false));
            orderCouponNo.setGoodsVpdKey(orderCoupon.getGoodsVpdKey());
            orderCouponNo.setGoodsVpdSource(orderCoupon.getGoodsVpdSource());
            orderCouponNo.setExpireStatus(false);
            orderCouponNo.setExceptionStatus(false);
            orderCouponNo.setStatus(OrderCouponNoStatusEnum.status1.getCode());

            if (goodsVpd.getSource().equals(GoodsVpdSourceEnum.type4.getCode())) {
                // 下单请求
                JSONObject jsonObject = HuiLianTongCouponService.recharge(orderCouponNo.getOrderNo(),
                        1,
                        orderCoupon.getGoodsVpdKey(),
                        orderCoupon.getUserPhone());
                if (!jsonObject.getString("respCode").equals("0000")) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "下单失败");
                }
                JSONObject response = HuiLianTongUnionCardService.resolveResponse(jsonObject.getString("data"));
                if (!response.getString("respCode").equals("0000")) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, response.getString("msg"));
                }
                orderCouponNo.setChannelOrderNo(response.getJSONObject("data").getString("rechargeOrderId"));
            }
            orderCouponNoService.editData(orderCouponNo);
        }

        return orderChild;
    }

    public OrderChildModel goods(OrderModel order, OrderChildModel orderChild) throws Exception {
        // 查询商品
        GoodsMsg goodsMsg = goodsMsgService.queryDetail(orderChild.getProductId());
        if (goodsMsg == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未知的商品");
        }
        if (goodsMsg.getStatus() != 1) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, goodsMsg.getTitle()+"暂无法就进行购买");
        }
        if (goodsMsg.getType() != 1) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "当前商品不属于实物产品不可下单！");
        }
        // 查询商品规格
        GoodsSpecs goodsSpecs = goodsSpecsService.queryDetail(orderChild.getProductSpecId());

        if (goodsSpecs == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未知的商品规格");
        }
        JSONObject object = new JSONObject((Map<String, Object>) orderChild.getBusiness());

        orderChild.setMerId(goodsMsg.getMerId());
        orderChild.setProductName(goodsMsg.getTitle());
        orderChild.setProductImg(goodsMsg.getListImg());
        orderChild.setProductSpecName(goodsSpecs.getName());
        orderChild.setProductPrice(goodsSpecs.getSalePrice());

        if (object == null || object.getLong("deliveryAddressId") == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请选择收货地址！");
        }

        // 查询收货地址
        GoodsUserAddress address = goodsUserAddressService.queryDetail(object.getLong("deliveryAddressId"));
        if (address == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未知的收货地址");
        }
        JSONObject jsonObject;
        if (orderChild.getBusiness() == null) {
            jsonObject = new JSONObject();
        } else {
            jsonObject = new JSONObject((Map<String, Object>) orderChild.getBusiness());
        }

        jsonObject.put("address", address);

        // 创建实物订单
        BsOrderGoods orderGoods = new BsOrderGoods();
        orderGoods.setOrderNo(orderChild.getOrderNo());
        orderGoods.setChildOrderNo(orderChild.getChildOrderNo());
        orderGoods.setMerId(orderChild.getMerId());
        orderGoods.setUserId(order.getUserId());
        orderGoods.setUserPhone(order.getUserPhone());
        orderGoods.setGoodsId(goodsMsg.getId());
        orderGoods.setImg(goodsSpecs.getShowImg());
        orderGoods.setGoodsName(goodsMsg.getTitle());
        orderGoods.setGoodsTypeId(goodsMsg.getGoodsType());
        orderGoods.setGoodsTypeName(goodsMsg.getGoodsTypeName());
        orderGoods.setGoodsBrandId(goodsMsg.getGoodsBrand());
        orderGoods.setGoodsBrandName(goodsMsg.getGoodsBrandName());
        orderGoods.setGoodsSpecsId(goodsSpecs.getId());
        orderGoods.setGoodsSpecsName(goodsSpecs.getName());
        orderGoods.setGoodsSpecsOriginalPrice(goodsSpecs.getOriginalPrice());
        orderGoods.setGoodsCount(orderChild.getProductCount());
        orderGoods.setStatus(OrderGoodsStatusEnum.status8.getCode());
        orderGoods.setDeliveryAddress(address.getAddress());
        orderGoods.setDeliveryAddressId(address.getId());
        orderGoods.setCreateTime(new Date());
        orderGoods.setUpdateTime(new Date());

        bsOrderGoodsService.create(orderGoods);

        goodsSpecsService.editStockNum(orderChild.getProductSpecId() , orderChild.getProductCount() , 2);

        jsonObject.put("orderGoodsId", orderGoods.getId());

        if (object.getLong("shopCartId") != null) {
            shoppingCartService.delete(object.getLong("shopCartId"));
        }

        orderChild.setBusiness(jsonObject);

        return orderChild;
    }
}
